@@ -13,12 +13,12 @@ def configure_logs():
     Takeover process logs and create a logger with Loguru according to the configuration
     """
     intercept_handler = InterceptHandler()
-    formatter = Formatter()
+    formatter = Formatter(opal_common_config.LOG_FORMAT)
     filter = ModuleFilter(include_list=opal_common_config.LOG_MODULE_INCLUDE_LIST, exclude_list=opal_common_config.LOG_MODULE_EXCLUDE_LIST)
     logging.basicConfig(handlers=[intercept_handler], level=0, force=True)
     if opal_common_config.LOG_PATCH_UVICORN_LOGS:
         # Monkey patch UVICORN to use our logger
-        hijack_uvicorn_logs()
+        hijack_uvicorn_logs(intercept_handler)
     # Clean slate
     logger.remove()
     # Logger configuration
@@ -30,6 +30,7 @@ def configure_logs():
         backtrace=opal_common_config.LOG_TRACEBACK,
         diagnose=opal_common_config.LOG_DIAGNOSE,
         colorize=opal_common_config.LOG_COLORIZE,
+        serialize=opal_common_config.LOG_SERIALIZE,
     )
     # log to a file
     if opal_common_config.LOG_TO_FILE:
